IcingaDB Redis v6.2.5

Renames several files to adhere to the icingadb-redis naming scheme#
Applies patches for changing the port from 6379 to 6380 and 26379 to 26380
This commit is contained in:
Henrik Triem 2021-07-29 12:13:18 +00:00 committed by Henrik Triem
parent 2c6fdd6170
commit bdade5bb1a
10 changed files with 509 additions and 59 deletions

229
.gitlab-ci.yml Normal file
View File

@ -0,0 +1,229 @@
stages:
- build
- test
- upload
variables:
DOCKER_IMAGE_BASE: registry.icinga.com/build-docker
.build: &build
stage: build
tags:
- docker
image: ${DOCKER_IMAGE_BASE}/${DOCKER_IMAGE}
script:
- icinga-build-package
cache:
key: "${CI_JOB_NAME}"
paths:
- ccache/
artifacts:
paths:
- build/*
expire_in: 1 week
.test: &test
stage: test
tags:
- docker
image: ${DOCKER_IMAGE_BASE}/${DOCKER_IMAGE}
script:
- find build/
- icinga-build-test
.upload: &upload
stage: upload
tags:
- docker
image: ${DOCKER_IMAGE_BASE}/upload
script:
- find build/
- icinga-build-upload-aptly
only:
- tags
###################################
# EPEL
###################################
build/centos/8:
<<: *build
variables:
DOCKER_IMAGE: centos/8
test/centos/8:
<<: *test
variables:
DOCKER_IMAGE: centos/8
dependencies:
- build/centos/8
upload/epel/8:
<<: *upload
dependencies:
- build/centos/8
build/centos/7:
<<: *build
variables:
DOCKER_IMAGE: centos/7
script:
- sudo yum install -y devtoolset-7-gcc\*
- . /opt/rh/devtoolset-7/enable; icinga-build-package
test/centos/7:
<<: *test
variables:
DOCKER_IMAGE: centos/7
dependencies:
- build/centos/7
upload/epel/7:
<<: *upload
dependencies:
- build/centos/7
###################################
# Fedora
###################################
build/fedora/34:
<<: *build
variables:
DOCKER_IMAGE: fedora/34
test/fedora/34:
<<: *test
variables:
DOCKER_IMAGE: fedora/34
dependencies:
- build/fedora/34
upload/fedora/34:
<<: *upload
dependencies:
- build/fedora/34
build/fedora/33:
<<: *build
variables:
DOCKER_IMAGE: fedora/33
test/fedora/33:
<<: *test
variables:
DOCKER_IMAGE: fedora/33
dependencies:
- build/fedora/33
upload/fedora/33:
<<: *upload
dependencies:
- build/fedora/33
build/fedora/32:
<<: *build
variables:
DOCKER_IMAGE: fedora/32
test/fedora/32:
<<: *test
variables:
DOCKER_IMAGE: fedora/32
dependencies:
- build/fedora/32
upload/fedora/32:
<<: *upload
dependencies:
- build/fedora/32
build/fedora/31:
<<: *build
variables:
DOCKER_IMAGE: fedora/31
test/fedora/31:
<<: *test
variables:
DOCKER_IMAGE: fedora/31
dependencies:
- build/fedora/31
upload/fedora/31:
<<: *upload
dependencies:
- build/fedora/31
###################################
# SLES
###################################
build/sles/15.3:
<<: *build
variables:
DOCKER_IMAGE: sles/15.3
test/sles/15.3:
<<: *test
variables:
DOCKER_IMAGE: sles/15.3
dependencies:
- build/sles/15.3
upload/SUSE/15.3:
<<: *upload
dependencies:
- build/sles/15.3
build/sles/15.2:
<<: *build
variables:
DOCKER_IMAGE: sles/15.2
test/sles/15.2:
<<: *test
variables:
DOCKER_IMAGE: sles/15.2
dependencies:
- build/sles/15.2
upload/SUSE/15.2:
<<: *upload
dependencies:
- build/sles/15.2
###################################
# openSUSE
###################################
build/opensuse/15.3:
<<: *build
variables:
DOCKER_IMAGE: opensuse/15.3
test/opensuse/15.3:
<<: *test
variables:
DOCKER_IMAGE: opensuse/15.3
dependencies:
- build/opensuse/15.3
upload/openSUSE/15.3:
<<: *upload
dependencies:
- build/opensuse/15.3
build/opensuse/15.2:
<<: *build
variables:
DOCKER_IMAGE: opensuse/15.2
test/opensuse/15.2:
<<: *test
variables:
DOCKER_IMAGE: opensuse/15.2
dependencies:
- build/opensuse/15.2
upload/openSUSE/15.2:
<<: *upload
dependencies:
- build/opensuse/15.2

5
icinga-build-test Executable file
View File

@ -0,0 +1,5 @@
#!/bin/bash
set -ex
icinga-build-rpm-install icingadb-redis

177
icinga-server-port.patch Normal file
View File

@ -0,0 +1,177 @@
Author: Henrik Triem <henrik.triem@icinga.com>
Date: Tue Jun 01 13:20:51 2021 +0100
Change default server port for icinga-redis
diff --git a/redis.conf b/redis.conf
index ab0a30cbd..d8e51f8ba 100644
--- a/redis.conf
+++ b/redis.conf
@@ -95,7 +95,7 @@
# Accept connections on the specified port, default is 6379 (IANA #815344).
# If port 0 is specified Redis will not listen on a TCP socket.
-port 6379
+port 6380
# TCP listen() backlog.
#
@@ -142,7 +142,7 @@
# default port, use:
#
# port 0
-# tls-port 6379
+# tls-port 6380
# Configure a X.509 certificate and private key to use for authenticating the
# server to connected clients, masters or cluster peers. These files should be
@@ -286,7 +286,7 @@
#
# Note that on modern Linux systems "/run/redis.pid" is more conforming
# and should be used instead.
-pidfile /var/run/redis_6379.pid
+pidfile /var/run/redis_6380.pid
# Specify the server verbosity level.
# This can be one of:
diff --git a/sentinel.conf b/sentinel.conf
index b6ff05f25..2d86376fd 100644
--- a/sentinel.conf
+++ b/sentinel.conf
@@ -18,7 +18,7 @@
# port <sentinel-port>
# The port that this sentinel instance will run on
-port 26379
+port 26380
# By default Redis Sentinel does not run as a daemon. Use 'yes' if you need it.
# Note that Redis will write a pid file in /var/run/redis-sentinel.pid when
@@ -81,7 +81,7 @@
#
# Note: master name should not include special characters or spaces.
# The valid charset is A-z 0-9 and the three characters ".-_".
-sentinel monitor mymaster 127.0.0.1 6379 2
+sentinel monitor mymaster 127.0.0.1 6380 2
# sentinel auth-pass <master-name> <password>
#
diff --git a/src/config.c b/src/config.c
index 4a956d698..bd3100db6 100644
--- a/src/config.c
+++ b/src/config.c
@@ -2475,7 +2475,7 @@
/* Integer configs */
createIntConfig("databases", NULL, IMMUTABLE_CONFIG, 1, INT_MAX, server.dbnum, 16, INTEGER_CONFIG, NULL, NULL),
- createIntConfig("port", NULL, MODIFIABLE_CONFIG, 0, 65535, server.port, 6379, INTEGER_CONFIG, NULL, updatePort), /* TCP port. */
+ createIntConfig("port", NULL, MODIFIABLE_CONFIG, 0, 65535, server.port, 6380, INTEGER_CONFIG, NULL, updatePort), /* TCP port. */
createIntConfig("io-threads", NULL, IMMUTABLE_CONFIG, 1, 128, server.io_threads_num, 1, INTEGER_CONFIG, NULL, NULL), /* Single threaded by default */
createIntConfig("auto-aof-rewrite-percentage", NULL, MODIFIABLE_CONFIG, 0, INT_MAX, server.aof_rewrite_perc, 100, INTEGER_CONFIG, NULL, NULL),
createIntConfig("cluster-replica-validity-factor", "cluster-slave-validity-factor", MODIFIABLE_CONFIG, 0, INT_MAX, server.cluster_slave_validity_factor, 10, INTEGER_CONFIG, NULL, NULL), /* Slave max data age factor. */
diff --git a/src/redis-benchmark.c b/src/redis-benchmark.c
index 9d9c15e00..ff72dc92b 100644
--- a/src/redis-benchmark.c
+++ b/src/redis-benchmark.c
@@ -1555,7 +1555,7 @@
printf(
"Usage: redis-benchmark [-h <host>] [-p <port>] [-c <clients>] [-n <requests>] [-k <boolean>]\n\n"
" -h <hostname> Server hostname (default 127.0.0.1)\n"
-" -p <port> Server port (default 6379)\n"
+" -p <port> Server port (default 6380)\n"
" -s <socket> Server socket (overrides host and port)\n"
" -a <password> Password for Redis Auth\n"
" --user <username> Used to send ACL style 'AUTH username pass'. Needs -a.\n"
@@ -1605,13 +1605,13 @@
" --help Output this help and exit.\n"
" --version Output version and exit.\n\n"
"Examples:\n\n"
-" Run the benchmark with the default configuration against 127.0.0.1:6379:\n"
+" Run the benchmark with the default configuration against 127.0.0.1:6380:\n"
" $ redis-benchmark\n\n"
" Use 20 parallel clients, for a total of 100k requests, against 192.168.1.1:\n"
-" $ redis-benchmark -h 192.168.1.1 -p 6379 -n 100000 -c 20\n\n"
-" Fill 127.0.0.1:6379 with about 1 million keys only using the SET test:\n"
+" $ redis-benchmark -h 192.168.1.1 -p 6380 -n 100000 -c 20\n\n"
+" Fill 127.0.0.1:6380 with about 1 million keys only using the SET test:\n"
" $ redis-benchmark -t set -n 1000000 -r 100000000\n\n"
-" Benchmark 127.0.0.1:6379 for a few commands producing CSV output:\n"
+" Benchmark 127.0.0.1:6380 for a few commands producing CSV output:\n"
" $ redis-benchmark -t ping,set,get -n 100000 --csv\n\n"
" Benchmark a specific command line:\n"
" $ redis-benchmark -r 10000 -n 10000 eval 'return redis.call(\"ping\")' 0\n\n"
@@ -1707,7 +1707,7 @@
config.idlemode = 0;
config.clients = listCreate();
config.hostip = "127.0.0.1";
- config.hostport = 6379;
+ config.hostport = 6380;
config.hostsocket = NULL;
config.tests = NULL;
config.dbnum = 0;
diff --git a/src/redis-cli.c b/src/redis-cli.c
index 45a1228e6..3259b0d37 100644
--- a/src/redis-cli.c
+++ b/src/redis-cli.c
@@ -1828,7 +1828,7 @@
"\n"
"Usage: redis-cli [OPTIONS] [cmd [arg [arg ...]]]\n"
" -h <hostname> Server hostname (default: 127.0.0.1).\n"
-" -p <port> Server port (default: 6379).\n"
+" -p <port> Server port (default: 6380).\n"
" -s <socket> Server socket (overrides hostname and port).\n"
" -a <password> Password to use when connecting to the server.\n"
" You can also use the " REDIS_CLI_AUTH_ENV " environment\n"
@@ -8200,7 +8200,7 @@
memset(&config.sslconfig, 0, sizeof(config.sslconfig));
config.hostip = sdsnew("127.0.0.1");
- config.hostport = 6379;
+ config.hostport = 6380;
config.hostsocket = NULL;
config.repeat = 1;
config.interval = 0;
diff --git a/src/sentinel.c b/src/sentinel.c
index 1bd82453f..d85ee6049 100644
--- a/src/sentinel.c
+++ b/src/sentinel.c
@@ -49,7 +49,7 @@
extern SSL_CTX *redis_tls_client_ctx;
#endif
-#define REDIS_SENTINEL_PORT 26379
+#define REDIS_SENTINEL_PORT 26380
/* ======================== Sentinel global state =========================== */
diff --git a/src/server.c b/src/server.c
index 831349a76..34b9eea3f 100644
--- a/src/server.c
+++ b/src/server.c
@@ -1479,7 +1479,7 @@
NULL /* allow to expand */
};
/* Cluster nodes hash table, mapping nodes addresses 1.2.3.4:6379 to
* clusterNode structures. */
dictType clusterNodesDictType = {
dictSdsHash, /* hash function */
@@ -2687,7 +2687,7 @@
/* Replication related */
server.masterauth = NULL;
server.masterhost = NULL;
- server.masterport = 6379;
+ server.masterport = 6380;
server.master = NULL;
server.cached_master = NULL;
server.master_initial_offset = -1;
@@ -5590,7 +5590,7 @@
fprintf(stderr," ./redis-server --test-memory <megabytes>\n\n");
fprintf(stderr,"Examples:\n");
fprintf(stderr," ./redis-server (run the server with default conf)\n");
- fprintf(stderr," ./redis-server /etc/redis/6379.conf\n");
+ fprintf(stderr," ./redis-server /etc/redis/6380.conf\n");
fprintf(stderr," ./redis-server --port 7777\n");
fprintf(stderr," ./redis-server --port 7777 --replicaof 127.0.0.1 8888\n");
fprintf(stderr," ./redis-server /etc/myredis.conf --loglevel verbose -\n");

View File

@ -1,2 +1,2 @@
%redis_modules_abi 1
%redis_modules_dir %{_libdir}/redis/modules
%redis_modules_dir %{_libdir}/icingadb-redis/modules

View File

@ -1,16 +1,16 @@
[Unit]
Description=Redis Sentinel
Description=IcingaDB Redis Sentinel
After=network.target
After=network-online.target
Wants=network-online.target
[Service]
ExecStart=/usr/bin/redis-sentinel /etc/redis/sentinel.conf --daemonize no --supervised systemd
ExecStop=/usr/libexec/redis-shutdown sentinel
ExecStart=/usr/bin/icingadb-redis-sentinel /etc/icingadb-redis/sentinel.conf --daemonize no --supervised systemd
ExecStop=/usr/libexec/icingadb-redis-shutdown sentinel
Type=notify
User=redis
Group=redis
RuntimeDirectory=redis
User=icingadb-redis
Group=icingadb-redis
RuntimeDirectory=icingadb-redis
RuntimeDirectoryMode=0755
[Install]

View File

@ -3,16 +3,16 @@
# Wrapper to close properly redis and sentinel
test x"$REDIS_DEBUG" != x && set -x
REDIS_CLI=/usr/bin/redis-cli
REDIS_CLI=/usr/bin/icingadb-redis-cli
# Retrieve service name
SERVICE_NAME="$1"
if [ -z "$SERVICE_NAME" ]; then
SERVICE_NAME=redis
SERVICE_NAME=icingadb-redis
fi
# Get the proper config file based on service name
CONFIG_FILE="/etc/redis/$SERVICE_NAME.conf"
CONFIG_FILE="/etc/icingadb-redis/$SERVICE_NAME.conf"
# Use awk to retrieve host, port from config file
HOST=`awk '/^[[:blank:]]*bind/ { print $2 }' $CONFIG_FILE | tail -n1`
@ -23,7 +23,7 @@ SOCK=`awk '/^[[:blank:]]*unixsocket\s/ { print $2 }' $CONFIG_FILE | tail -n1`
# Just in case, use default host, port
HOST=${HOST:-127.0.0.1}
if [ "$SERVICE_NAME" = redis ]; then
PORT=${PORT:-6379}
PORT=${PORT:-6380}
else
PORT=${PORT:-26739}
fi

View File

@ -1,4 +1,4 @@
/var/log/redis/*.log {
/var/log/icingadb-redis/*.log {
weekly
rotate 10
copytruncate

View File

@ -1,16 +1,16 @@
[Unit]
Description=Redis persistent key-value database
Description=IcingaDB Redis persistent key-value database
After=network.target
After=network-online.target
Wants=network-online.target
[Service]
ExecStart=/usr/bin/redis-server /etc/redis/redis.conf --daemonize no --supervised systemd
ExecStop=/usr/libexec/redis-shutdown
ExecStart=/usr/bin/icingadb-redis-server /etc/icingadb-redis/icingadb-redis.conf --daemonize no --supervised systemd
ExecStop=/usr/libexec/icingadb-redis-shutdown
Type=notify
User=redis
Group=redis
RuntimeDirectory=redis
User=icingadb-redis
Group=icingadb-redis
RuntimeDirectory=icingadb-redis
RuntimeDirectoryMode=0755
[Install]

View File

@ -12,28 +12,32 @@
# Commit IDs for the (unversioned) redis-doc repository
# https://fedoraproject.org/wiki/Packaging:SourceURL "Commit Revision"
%global doc_commit 9fe1f36dd716ea982b8917f2bdb70ec4bfc3219b
%global doc_commit 6a9c6310b7291d802cf2fbc45b742e97e2804413
%global short_doc_commit %(c=%{doc_commit}; echo ${c:0:7})
# %%{rpmmacrodir} not usable on EL-6
%global macrosdir %(d=%{_rpmconfigdir}/macros.d; [ -d $d ] || d=%{_sysconfdir}/rpm; echo $d)
Name: redis
Version: 6.2.4
%global pkg_prefix icingadb-
%global src_name redis
%global redis_port 6380
Name: %{?pkg_prefix}redis
Version: 6.2.5
Release: 1%{?dist}
Summary: A persistent key-value database
# redis, jemalloc, linenoise, lzf, hiredis are BSD
# lua is MIT
License: BSD and MIT
URL: https://redis.io
Source0: https://download.redis.io/releases/%{name}-%{version}.tar.gz
Source1: %{name}.logrotate
Source2: %{name}-sentinel.service
Source3: %{name}.service
Source6: %{name}-shutdown
Source7: %{name}-limit-systemd
Source9: macros.%{name}
Source10: https://github.com/%{name}/%{name}-doc/archive/%{doc_commit}/%{name}-doc-%{short_doc_commit}.tar.gz
Source0: https://download.redis.io/releases/%{src_name}-%{version}.tar.gz
Source1: %{src_name}.logrotate
Source2: %{src_name}-sentinel.service
Source3: %{src_name}.service
Source6: %{src_name}-shutdown
Source7: %{src_name}-limit-systemd
Source9: macros.%{src_name}
Source10: https://github.com/%{src_name}/%{src_name}-doc/archive/%{doc_commit}/%{src_name}-doc-%{short_doc_commit}.tar.gz
# To refresh patches:
# tar xf redis-xxx.tar.gz && cd redis-xxx && git init && git add . && git commit -m "%%{version} baseline"
@ -43,6 +47,8 @@ Source10: https://github.com/%{name}/%{name}-doc/archive/%{doc_commit}/
# Update configuration for Fedora
# https://github.com/redis/redis/pull/3491 - man pages
Patch0001: 0001-1st-man-pageis-for-redis-cli-redis-benchmark-redis-c.patch
# Update default port from 6370 to 6380
Patch0901: icinga-server-port.patch
BuildRequires: make
BuildRequires: gcc
@ -58,7 +64,11 @@ Obsoletes: redis-trib < 5
# Required for redis-shutdown
Requires: /bin/awk
Requires: logrotate
%if "%{_vendor}" == "suse"
Requires(pre): shadow
%else
Requires(pre): shadow-utils
%endif
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd
@ -104,7 +114,7 @@ You can use Redis from most programming languages also.
%package devel
Summary: Development header for Redis module development
# Header-Only Library (https://fedoraproject.org/wiki/Packaging:Guidelines)
Provides: %{name}-static = %{version}-%{release}
Provides: %{src_name}-static = %{version}-%{release}
%description devel
Header file required for building loadable Redis modules. Detailed
@ -124,19 +134,28 @@ administration and development.
%prep
%setup -q -b 10
%setup -q
mv ../%{name}-doc-%{doc_commit} doc
%setup -q -b 10 -n %{src_name}-%{version}
%setup -q -n %{src_name}-%{version}
mv ../%{src_name}-doc-%{doc_commit} doc
%patch0001 -p1
%patch0901 -p1
mv deps/lua/COPYRIGHT COPYRIGHT-lua
mv deps/jemalloc/COPYING COPYING-jemalloc
mv deps/hiredis/COPYING COPYING-hiredis
# Configuration file changes
sed -i -e 's|^logfile .*$|logfile /var/log/redis/redis.log|g' redis.conf
sed -i -e 's|^logfile .*$|logfile /var/log/redis/sentinel.log|g' sentinel.conf
sed -i -e 's|^dir .*$|dir /var/lib/redis|g' redis.conf
sed -i -e 's|^logfile .*$|logfile /var/log/%{name}/redis.log|g' redis.conf
sed -i -e 's|^logfile .*$|logfile /var/log/%{name}/sentinel.log|g' sentinel.conf
sed -i -e 's|^dir .*$|dir /var/lib/%{name}|g' redis.conf
# Update redis port in config
sed -i -e 's|^port .*$|port %{redis_port}|'g redis.conf
sed -i -e 's|^port .*$|port 2%{redis_port}|'g sentinel.conf
# Update PID file in config
sed -i -e 's|^pidfile .*$|pidfile /var/run/%{name}/redis.pid|g' redis.conf
sed -i -e 's|^pidfile .*$|pidfile /var/run/%{name}/redis-sentinel.pid|g' sentinel.conf
# Module API version safety check
api=`sed -n -e 's/#define REDISMODULE_APIVER_[0-9][0-9]* //p' src/redismodule.h`
@ -164,34 +183,51 @@ install -d %{buildroot}%{redis_modules_dir}
install -pDm644 %{S:1} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
# Install configuration files.
install -pDm640 %{name}.conf %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf
#newicingaline1
install -pd %{buildroot}%{_sysconfdir}/%{name}
install -pDm640 %{src_name}.conf %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf
install -pDm640 sentinel.conf %{buildroot}%{_sysconfdir}/%{name}/sentinel.conf
# Install systemd unit files.
mkdir -p %{buildroot}%{_unitdir}
install -pm644 %{S:3} %{buildroot}%{_unitdir}
install -pm644 %{S:2} %{buildroot}%{_unitdir}
install -pm644 %{S:3} %{buildroot}%{_unitdir}/%{name}.service
install -pm644 %{S:2} %{buildroot}%{_unitdir}/%{name}-sentinel.service
# Install systemd limit files (requires systemd >= 204)
install -p -D -m 644 %{S:7} %{buildroot}%{_sysconfdir}/systemd/system/%{name}.service.d/limit.conf
install -p -D -m 644 %{S:7} %{buildroot}%{_sysconfdir}/systemd/system/%{name}-sentinel.service.d/limit.conf
# Fix non-standard-executable-perm error.
chmod 755 %{buildroot}%{_bindir}/%{name}-*
#newicingaline5
for bin in $(cd %{buildroot}%{_bindir}; ls redis*); do
# Rename bin file and add prefix if set
[ -z %{?pkg_prefix} ] || mv %{buildroot}%{_bindir}/${bin} %{buildroot}%{_bindir}/%{?pkg_prefix}${bin}
chmod 755 %{buildroot}%{_bindir}/%{?pkg_prefix}${bin}
done
# Fix symlinks for checks
#newicingaline4
if [ -n %{?pkg_prefix} ]; then
ln -svf %{name}-server %{buildroot}%{_bindir}/%{name}-check-aof
ln -svf %{name}-server %{buildroot}%{_bindir}/%{name}-check-rdb
fi
# Install redis-shutdown
install -pDm755 %{S:6} %{buildroot}%{_libexecdir}/%{name}-shutdown
# Install redis module header
install -pDm644 src/%{name}module.h %{buildroot}%{_includedir}/%{name}module.h
install -pDm644 src/%{src_name}module.h %{buildroot}%{_includedir}/%{name}module.h
# Install man pages
man=$(dirname %{buildroot}%{_mandir})
for page in man/man?/*; do
install -Dpm644 $page $man/$page
#newicingaline3
dir=$(dirname $page)
file=$(basename $page)
install -Dpm644 $page $man/$dir/%{?pkg_prefix}$file
done
ln -s redis-server.1 %{buildroot}%{_mandir}/man1/redis-sentinel.1
ln -s redis.conf.5 %{buildroot}%{_mandir}/man5/redis-sentinel.conf.5
ln -s redis-server.1 %{buildroot}%{_mandir}/man1/%{pkg_prefix}redis-sentinel.1
ln -s redis.conf.5 %{buildroot}%{_mandir}/man5/%{pkg_prefix}redis-sentinel.conf.5
# Install documentation and html pages
doc=$(echo %{buildroot}/%{_docdir}/%{name})
@ -260,13 +296,13 @@ fi
%license COPYING-jemalloc
%license COPYING-hiredis
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%attr(0750, redis, root) %dir %{_sysconfdir}/%{name}
%attr(0640, redis, root) %config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%attr(0640, redis, root) %config(noreplace) %{_sysconfdir}/%{name}/sentinel.conf
%dir %attr(0750, redis, redis) %{_libdir}/%{name}
%dir %attr(0750, redis, redis) %{redis_modules_dir}
%dir %attr(0750, redis, redis) %{_sharedstatedir}/%{name}
%dir %attr(0750, redis, redis) %{_localstatedir}/log/%{name}
%attr(0750, %{name}, root) %dir %{_sysconfdir}/%{name}
%attr(0640, %{name}, root) %config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%attr(0640, %{name}, root) %config(noreplace) %{_sysconfdir}/%{name}/sentinel.conf
%dir %attr(0750, %{name}, %{name}) %{_libdir}/%{name}
%dir %attr(0750, %{name}, %{name}) %{redis_modules_dir}
%dir %attr(0750, %{name}, %{name}) %{_sharedstatedir}/%{name}
%dir %attr(0750, %{name}, %{name}) %{_localstatedir}/log/%{name}
%exclude %{macrosdir}
%exclude %{_includedir}
%exclude %{_docdir}/%{name}/*
@ -280,11 +316,11 @@ fi
%config(noreplace) %{_sysconfdir}/systemd/system/%{name}.service.d/limit.conf
%dir %{_sysconfdir}/systemd/system/%{name}-sentinel.service.d
%config(noreplace) %{_sysconfdir}/systemd/system/%{name}-sentinel.service.d/limit.conf
%dir %attr(0755, redis, redis) %ghost %{_localstatedir}/run/%{name}
%dir %attr(0755, %{name}, %{name}) %ghost %{_localstatedir}/run/%{name}
%files devel
# main package is not required
%license COPYING
# specific for documentation (CC-BY-SA)
%license doc/LICENSE
%{_includedir}/%{name}module.h
%{macrosdir}/*
@ -296,8 +332,11 @@ fi
%changelog
* Wed Jun 2 2021 Remi Collet <remi@remirepo.net> - 6.2.4-1
- Upstream 6.2.4 release.
* Thu Jul 29 2021 Henrik Triem <henrik.triem@icinga.com> - 6.2.5-1
- Update to 6.2.5-1
* Wed Jun 30 2021 Henrik Triem <henrik.triem@icinga.com> - 6.2.4-1
- Update to 6.2.4-1
* Tue May 4 2021 Remi Collet <remi@remirepo.net> - 6.2.3-1
- Upstream 6.2.3 release

View File

@ -1,2 +1,2 @@
SHA512 (redis-6.2.4.tar.gz) = 22db5b64de20a4823fd219b559c05f329e37fc86ce32099c64655dc50e60228706c99bffeae8d7080d8689910879318ec6621388bde23bf1486aefb881f33cb0
SHA512 (redis-doc-9fe1f36.tar.gz) = 515976937182acf5d76efb16cdd9fe8fe4d9996306459ca6b1a80a89d877719a174014cffec2c6fe25b407c4356b4337ad8bae05c63b3d9449ee5d68d0f34e59
SHA512 (redis-6.2.5.tar.gz) = 8c54451032cbb627ec2827251556cba2010e56544baca7ea117b5afd2c2add484acbedd3baf21bdb8fd10672602cf52294a4e26b135c1406d7a723c048275e3a
@@ -1479,7 +1479,7 @@
NULL /* allow to expand */
};
-/* Cluster nodes hash table, mapping nodes addresses 1.2.3.4:6379 to
+/* Cluster nodes hash table, mapping nodes addresses 1.2.3.4:6380 to
* clusterNode structures. */
dictType clusterNodesDictType = {
SHA512 (redis-doc-6a9c631.tar.gz) = 9882c19fad9efd38e999b036b7372a0c445c8d09512706f16e43ab5ac1c7c93380489a12b94028750386f0b553e8e10ec82db60e505c3645ed0cbd07b9305ed9